@@ -197,11 +197,15 @@ make_current (GtkWidget *widget, ClockLocationTile *tile)
 	GtkWidget *toplevel;
 	guint xid;
 
+	xid = 0;
 	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (tile));
-	if (toplevel && toplevel->window)
-		xid = GDK_WINDOW_XWINDOW (toplevel->window);
-	else
-		xid = 0;
+
+	if (toplevel) {
+		GdkWindow *window = gtk_widget_get_window (toplevel);
+
+		if (window)
+			xid = GDK_WINDOW_XWINDOW (window);
+	}
 
 	clock_location_make_current (priv->location,
 				     xid,
@@ -546,7 +550,7 @@ clock_location_tile_refresh (ClockLocationTile *this, gboolean force_refresh)
 		gtk_widget_show (priv->current_marker);
 	}
 	else {
-		if (GTK_WIDGET_VISIBLE (priv->current_marker)) {
+		if (gtk_widget_get_visible (priv->current_marker)) {
 			gtk_widget_hide (priv->current_marker);
 			gtk_widget_hide (priv->current_button);
 			gtk_widget_show (priv->current_spacer);
@@ -599,7 +603,8 @@ weather_info_setup_tooltip (WeatherInfo *info, ClockLocation *location, GtkToolt
 
        	icon_name = weather_info_get_icon_name (info);
         theme = gtk_icon_theme_get_default ();
-        pixbuf = gtk_icon_theme_load_icon (theme, icon_name, 48, 0, NULL);
+        pixbuf = gtk_icon_theme_load_icon (theme, icon_name, 48,
+                                           GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
         if (pixbuf)
                 gtk_tooltip_set_icon (tooltip, pixbuf);
 
@@ -701,7 +706,8 @@ update_weather_icon (ClockLocation *loc, WeatherInfo *info, gpointer data)
 
         icon_name = weather_info_get_icon_name (info);
         theme = gtk_icon_theme_get_default ();
-        pixbuf = gtk_icon_theme_load_icon (theme, icon_name, 16, 0, NULL);
+        pixbuf = gtk_icon_theme_load_icon (theme, icon_name, 16,
+                                           GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
 
         if (pixbuf) {
                 gtk_image_set_from_pixbuf (GTK_IMAGE (priv->weather_icon), pixbuf);
