@@ -34,10 +34,10 @@ void panel_compatibility_migrate_panel_id_list (GConfClient *client);
 void panel_compatibility_maybe_copy_old_config (GConfClient *client);
 void panel_compatibility_migrate_applications_scheme (GConfClient *client,
 						      const char  *key);
-void panel_compatiblity_migrate_screenshot_action (GConfClient *client,
+void panel_compatibility_migrate_screenshot_action (GConfClient *client,
 						   const char  *id);
 
-gchar *panel_compatiblity_get_applet_iid (const gchar *id);
+gchar *panel_compatibility_get_applet_iid (const gchar *id);
 
 G_END_DECLS
 
