@@ -35,6 +35,7 @@
 #include <gdk/gdkkeysyms.h>
 
 #include <libpanel-util/panel-error.h>
+#include <libpanel-util/panel-show.h>
 
 #include "nothing.h"
 #include "panel-util.h"
@@ -53,7 +54,7 @@ panel_context_menu_show_help (GtkWidget *w,
 			      gpointer data)
 {
 	panel_show_help (gtk_widget_get_screen (w),
-			 "user-guide.xml", "gospanel-1");
+			 "user-guide", "gospanel-1", NULL);
 }
 
 static gboolean
@@ -80,33 +81,33 @@ panel_context_menu_show_about_dialog (GtkWidget *menuitem)
 {
 	static GtkWidget *about = NULL;
 	char             *authors [] = {
-		"Alex Larsson (alexl@redhat.com)",
-		"Anders Carlsson (andersca@gnu.org)",
-		"Arvind Samptur (arvind.samptur@wipro.com)",
-		"Darin Adler (darin@bentspoon.com)",
-		"Elliot Lee (sopwith@redhat.com)",
-		"Federico Mena (quartic@gimp.org)",
-		"George Lebl (jirka@5z.com)",
-		"Glynn Foster (glynn.foster@sun.com)",
-		"Ian Main (imain@gtk.org)",
+		"Alex Larsson <alexl@redhat.com>",
+		"Anders Carlsson <andersca@gnu.org>",
+		"Arvind Samptur <arvind.samptur@wipro.com>",
+		"Darin Adler <darin@bentspoon.com>",
+		"Elliot Lee <sopwith@redhat.com>",
+		"Federico Mena <quartic@gimp.org>",
+		"George Lebl <jirka@5z.com>",
+		"Glynn Foster <glynn.foster@sun.com>",
+		"Ian Main <imain@gtk.org>",
 		"Ian McKellar <yakk@yakk.net>",
-		"Jacob Berkman (jberkman@andrew.cmu.edu)",
-		"Mark McLoughlin (mark@skynet.ie)",
-		"Martin Baulig (baulig@suse.de)",
-		"Miguel de Icaza (miguel@kernel.org)",
-		"Owen Taylor (otaylor@redhat.com)",
-		"Padraig O'Briain (padraig.obriain@sun.com)",
-		"Seth Nickell (snickell@stanford.edu)",
-		"Stephen Browne (stephen.browne@sun.com)",
-		"Tom Tromey (tromey@cygnus.com)",
-		"Vincent Untz (vuntz@gnome.org)",
+		"Jacob Berkman <jberkman@andrew.cmu.edu>",
+		"Mark McLoughlin <mark@skynet.ie>",
+		"Martin Baulig <baulig@suse.de>",
+		"Miguel de Icaza <miguel@kernel.org>",
+		"Owen Taylor <otaylor@redhat.com>",
+		"Padraig O'Briain <padraig.obriain@sun.com>",
+		"Seth Nickell <snickell@stanford.edu>",
+		"Stephen Browne <stephen.browne@sun.com>",
+		"Tom Tromey <tromey@cygnus.com>",
+		"Vincent Untz <vuntz@gnome.org>",
 		N_("And many, many others..."),
 		NULL
 	};
 	char *documenters[] = {
-	        "Alexander Kirillov (kirillov@math.sunysb.edu)",
-		"Dan Mueth (d-mueth@uchicago.edu)",
-		"Dave Mason (dcm@redhat.com)",
+	        "Alexander Kirillov <kirillov@math.sunysb.edu>",
+		"Dan Mueth <d-mueth@uchicago.edu>",
+		"Dave Mason <dcm@redhat.com>",
 		NULL
 	  };
 	int   i;
@@ -133,6 +134,7 @@ panel_context_menu_show_about_dialog (GtkWidget *menuitem)
 				    "applications and provides useful utilities."),
 		      "authors", authors,
 		      "documenters", documenters,
+		      "title", _("About the GNOME Panel"),
 		      "translator-credits", _("translator-credits"),
 		      "logo-icon-name", PANEL_ICON_PANEL,
 		      NULL);
@@ -275,6 +277,7 @@ panel_context_menu_create (PanelWidget *panel)
 	}
 
 	retval = create_empty_menu ();
+	gtk_widget_set_name (retval, "gnome-panel-context-menu");
 
 	if (!panel_lockdown_get_locked_down ())
 		panel_context_menu_build_edition (panel, retval);
