@@ -44,12 +44,13 @@ static Atom wm_state_atom = None;
 static GtkWidget *
 display_popup_window (GdkScreen *screen)
 {
-	GtkWidget *retval;
-	GtkWidget *vbox;
-	GtkWidget *image;
-	GtkWidget *frame;
-	GtkWidget *label;
-	int        screen_width, screen_height;
+	GtkWidget     *retval;
+	GtkWidget     *vbox;
+	GtkWidget     *image;
+	GtkWidget     *frame;
+	GtkWidget     *label;
+	int            screen_width, screen_height;
+	GtkAllocation  allocation;
 
 	retval = gtk_window_new (GTK_WINDOW_POPUP);
 	atk_object_set_role (gtk_widget_get_accessible (retval), ATK_ROLE_ALERT);
@@ -85,9 +86,11 @@ display_popup_window (GdkScreen *screen)
 	screen_width  = gdk_screen_get_width  (screen);
 	screen_height = gdk_screen_get_height (screen);
 
+	gtk_widget_get_allocation (retval, &allocation);
+
 	gtk_window_move (GTK_WINDOW (retval),
-			 (screen_width  - retval->allocation.width) / 2,
-			 (screen_height - retval->allocation.height) / 2);
+			 (screen_width  - allocation.width) / 2,
+			 (screen_height - allocation.height) / 2);
 
 	gtk_widget_show (GTK_WIDGET (retval));
 
@@ -109,7 +112,8 @@ remove_popup (GtkWidget *popup)
 }
 
 static gboolean
-wm_state_set (Window window)
+wm_state_set (Display *display,
+	      Window   window)
 {
 	gulong  nitems;
 	gulong  bytes_after;
@@ -119,7 +123,7 @@ wm_state_set (Window window)
 	int     result;
 
 	gdk_error_trap_push ();
-	result = XGetWindowProperty (gdk_display, window, wm_state_atom,
+	result = XGetWindowProperty (display, window, wm_state_atom,
 				     0, G_MAXLONG, False, wm_state_atom,
 				     &ret_type, &ret_format, &nitems,
 				     &bytes_after, (gpointer) &prop);
@@ -139,7 +143,8 @@ wm_state_set (Window window)
 }
 
 static Window 
-find_managed_window (Window window)
+find_managed_window (Display *display,
+		     Window   window)
 {
 	Window  root;
 	Window  parent;
@@ -148,23 +153,23 @@ find_managed_window (Window window)
 	guint   nkids;
 	int     i, result;
 
-	if (wm_state_set (window))
+	if (wm_state_set (display, window))
 		return window;
 
 	gdk_error_trap_push ();
-	result = XQueryTree (gdk_display, window, &root, &parent, &kids, &nkids);
+	result = XQueryTree (display, window, &root, &parent, &kids, &nkids);
 	if (gdk_error_trap_pop () || !result)
 		return None;
 
 	retval = None;
 
 	for (i = 0; i < nkids; i++) {
-		if (wm_state_set (kids [i])) {
+		if (wm_state_set (display, kids [i])) {
 			retval = kids [i];
 			break;
 		}
 
-		retval = find_managed_window (kids [i]);
+		retval = find_managed_window (display, kids [i]);
 		if (retval != None)
 			break;
 	}
@@ -181,10 +186,13 @@ kill_window_response (GtkDialog *dialog,
 		      gpointer   user_data)
 {
 	if (response_id == GTK_RESPONSE_ACCEPT) {
+		Display *display;
 		Window window = (Window) user_data;
 
+		display = GDK_DISPLAY_XDISPLAY (gtk_widget_get_display (GTK_WIDGET (dialog)));
+
 		gdk_error_trap_push ();
-		XKillClient (gdk_display, window);
+		XKillClient (display, window);
 		gdk_flush ();
 		gdk_error_trap_pop ();
 	}
@@ -238,12 +246,12 @@ handle_button_press_event (GtkWidget *popup,
 		return;
 
 	if (wm_state_atom == None)
-		wm_state_atom = XInternAtom (gdk_display, "WM_STATE", FALSE);
+		wm_state_atom = XInternAtom (event->display, "WM_STATE", FALSE);
 
-	window = find_managed_window (event->subwindow);
+	window = find_managed_window (event->display, event->subwindow);
 
 	if (window != None) {
-		if (!gdk_xid_table_lookup_for_display (gdk_display_get_default (), window))
+		if (!gdk_xid_table_lookup_for_display (gdk_x11_lookup_xdisplay (event->display), window))
 			kill_window_question ((gpointer) window);
 	}
 }
@@ -260,7 +268,7 @@ popup_filter (GdkXEvent *gdk_xevent,
 		handle_button_press_event (popup, &xevent->xkey);
 		return GDK_FILTER_REMOVE;
 	case KeyPress:
-		if (xevent->xkey.keycode == XKeysymToKeycode (gdk_display, XK_Escape)) {
+		if (xevent->xkey.keycode == XKeysymToKeycode (xevent->xany.display, XK_Escape)) {
 			remove_popup (popup);
 			return GDK_FILTER_REMOVE;
 		}
