@@ -32,6 +32,8 @@
 #include <gmenu-tree.h>
 
 #include <libpanel-util/panel-error.h>
+#include <libpanel-util/panel-launch.h>
+#include <libpanel-util/panel-show.h>
 
 #include "applet.h"
 #include "panel-widget.h"
@@ -305,11 +307,13 @@ panel_menu_button_parent_set (GtkWidget *widget,
 			      GtkWidget *previous_parent)
 {
 	PanelMenuButton *button = PANEL_MENU_BUTTON (widget);
+	GtkWidget       *parent;
 
-	g_return_if_fail (!widget->parent || PANEL_IS_WIDGET (widget->parent));
+	parent = gtk_widget_get_parent (widget);
+	g_return_if_fail (!parent || PANEL_IS_WIDGET (parent));
 
-	if (widget->parent)
-		button->priv->toplevel = PANEL_WIDGET (widget->parent)->toplevel;
+	if (parent)
+		button->priv->toplevel = PANEL_WIDGET (parent)->toplevel;
 	else
 		button->priv->toplevel = NULL;
 
@@ -334,7 +338,7 @@ panel_menu_button_drag_data_get (GtkWidget        *widget,
 	drag_data = g_strdup_printf ("MENU:%d", panel_find_applet_index (widget));
 
 	gtk_selection_data_set (
-		selection_data, selection_data->target,
+		selection_data, gtk_selection_data_get_target (selection_data),
 		8, (guchar *) drag_data, strlen (drag_data));
 
 	g_free (drag_data);
@@ -347,7 +351,6 @@ panel_menu_button_menu_deactivated (PanelMenuButton *button)
 
 	GTK_BUTTON (button)->in_button = FALSE;
 	button_widget_set_ignore_leave (BUTTON_WIDGET (button), FALSE);
-	gtk_button_released (GTK_BUTTON (button));
 }
 
 static void 
@@ -384,7 +387,8 @@ panel_menu_button_create_menu (PanelMenuButton *button)
 
 		filename = panel_menu_path_root_to_filename (button->priv->path_root);
 		button->priv->menu = create_applications_menu (filename,
-							       button->priv->menu_path);
+							       button->priv->menu_path,
+							       TRUE);
 	} else
 		button->priv->menu = create_main_menu (panel_widget);
 
@@ -969,35 +973,21 @@ panel_menu_button_invoke_menu (PanelMenuButton *button,
 	screen = gtk_widget_get_screen (GTK_WIDGET (button));
 
 	if (!strcmp (callback_name, "help")) {
-		panel_show_help (screen, "user-guide.xml", "gospanel-37");
+		panel_show_help (screen, "user-guide", "gospanel-37", NULL);
 
 	} else if (!strcmp (callback_name, "edit")) {
                 GError *error = NULL;
 
-		panel_launch_desktop_file ("alacarte.desktop",
-					   "alacarte-editor",
-					   screen,
-					   &error);
+		panel_launch_desktop_file_with_fallback ("alacarte.desktop",
+							 "alacarte",
+							 screen, &error);
 		if (error) {
 			g_error_free (error);
-			error = NULL;
-			panel_launch_desktop_file ("gmenu-simple-editor.desktop",
-						   "gmenu-simple-editor",
-						   screen,
-						   &error);
+			panel_launch_desktop_file_with_fallback (
+						"gmenu-simple-editor.desktop",
+						"gmenu-simple-editor",
+						screen, NULL);
 		}
-
-                if (error) {
-			char *primary;
-			primary = g_strdup_printf (_("Could not execute '%s'"),
-						   "gmenu-simple-editor");
-                        panel_error_dialog (NULL, screen,
-                                            "cannot_exec_gmenu-simple-editor",
-					    TRUE,
-					    primary, error->message);
-			g_free (primary);
-                        g_error_free (error);
-                }
 	}
 }
 
@@ -1018,7 +1008,7 @@ panel_menu_button_set_dnd_enabled (PanelMenuButton *button,
 		};
 		char *icon;
 
-		GTK_WIDGET_UNSET_FLAGS (button, GTK_NO_WINDOW);
+		gtk_widget_set_has_window (GTK_WIDGET (button), TRUE);
 		gtk_drag_source_set (GTK_WIDGET (button), GDK_BUTTON1_MASK,
 				     dnd_targets, 1,
 				     GDK_ACTION_COPY | GDK_ACTION_MOVE);
@@ -1030,7 +1020,7 @@ panel_menu_button_set_dnd_enabled (PanelMenuButton *button,
 			g_free (icon);
 		}
 
-		GTK_WIDGET_SET_FLAGS (button, GTK_NO_WINDOW);
+		gtk_widget_set_has_window (GTK_WIDGET (button), FALSE);
 	} else
 		gtk_drag_source_unset (GTK_WIDGET (button));
 }
@@ -1055,7 +1045,11 @@ panel_menu_button_accessible_get_n_children (AtkObject *obj)
 {
 	g_return_val_if_fail (PANEL_IS_MENU_BUTTON_ACCESSIBLE (obj), 0);
 
+#if GTK_CHECK_VERSION (2, 21, 0)
+	return gtk_accessible_get_widget (GTK_ACCESSIBLE (obj)) ? 1 : 0;
+#else
 	return GTK_ACCESSIBLE (obj)->widget ? 1 : 0;
+#endif
 }
 
 static AtkObject *
@@ -1070,7 +1064,11 @@ panel_menu_button_accessible_ref_child (AtkObject *obj,
 	if (index != 0)
 		return NULL;
 
+#if GTK_CHECK_VERSION (2, 21, 0)
+	if (!(button = PANEL_MENU_BUTTON (gtk_accessible_get_widget (GTK_ACCESSIBLE (obj)))))
+#else
 	if (!(button = PANEL_MENU_BUTTON (GTK_ACCESSIBLE (obj)->widget)))
+#endif
 		return NULL;
 
 	if (!(menu = panel_menu_button_create_menu (button)))
